@@ -35,6 +35,7 @@ struct _EvDocumentModel
 	gint rotation;
 	gdouble scale;
 	EvSizingMode sizing_mode;
+	EvPageLayout page_layout;
 	guint continuous : 1;
 	guint dual_page  : 1;
 	guint dual_page_odd_left : 1;
@@ -66,7 +67,10 @@ enum {
 	PROP_CONTINUOUS,
 	PROP_DUAL_PAGE,
 	PROP_DUAL_PAGE_ODD_LEFT,
-	PROP_FULLSCREEN
+	PROP_FULLSCREEN,
+	PROP_MIN_SCALE,
+	PROP_MAX_SCALE,
+	PROP_PAGE_LAYOUT
 };
 
 enum
@@ -79,6 +83,9 @@ static guint signals[N_SIGNALS] = { 0 };
 
 G_DEFINE_TYPE (EvDocumentModel, ev_document_model, G_TYPE_OBJECT)
 
+#define DEFAULT_MIN_SCALE 0.25
+#define DEFAULT_MAX_SCALE 5.0
+
 static void
 ev_document_model_finalize (GObject *object)
 {
@@ -116,12 +123,21 @@ ev_document_model_set_property (GObject      *object,
 	case PROP_SCALE:
 		ev_document_model_set_scale (model, g_value_get_double (value));
 		break;
+	case PROP_MIN_SCALE:
+		ev_document_model_set_min_scale (model, g_value_get_double (value));
+		break;
+	case PROP_MAX_SCALE:
+		ev_document_model_set_max_scale (model, g_value_get_double (value));
+		break;
 	case PROP_SIZING_MODE:
 		ev_document_model_set_sizing_mode (model, g_value_get_enum (value));
 		break;
 	case PROP_CONTINUOUS:
 		ev_document_model_set_continuous (model, g_value_get_boolean (value));
 		break;
+	case PROP_PAGE_LAYOUT:
+		ev_document_model_set_page_layout (model, g_value_get_enum (value));
+		break;
 	case PROP_DUAL_PAGE:
 		ev_document_model_set_dual_page (model, g_value_get_boolean (value));
 		break;
@@ -160,12 +176,21 @@ ev_document_model_get_property (GObject    *object,
 	case PROP_SCALE:
 		g_value_set_double (value, model->scale);
 		break;
+	case PROP_MIN_SCALE:
+		g_value_set_double (value, model->min_scale);
+		break;
+	case PROP_MAX_SCALE:
+		g_value_set_double (value, model->max_scale);
+		break;
 	case PROP_SIZING_MODE:
 		g_value_set_enum (value, model->sizing_mode);
 		break;
 	case PROP_CONTINUOUS:
 		g_value_set_boolean (value, ev_document_model_get_continuous (model));
 		break;
+	case PROP_PAGE_LAYOUT:
+		g_value_set_enum (value, model->page_layout);
+		break;
 	case PROP_DUAL_PAGE:
 		g_value_set_boolean (value, ev_document_model_get_dual_page (model));
 		break;
@@ -230,6 +255,22 @@ ev_document_model_class_init (EvDocumentModelClass *klass)
 							      0., G_MAXDOUBLE, 1.,
 							      G_PARAM_READWRITE |
                                                               G_PARAM_STATIC_STRINGS));
+	g_object_class_install_property (g_object_class,
+					 PROP_SCALE,
+					 g_param_spec_double ("min-scale",
+							      "Minimum Scale",
+							      "Minium scale factor",
+							      0., G_MAXDOUBLE, DEFAULT_MIN_SCALE,
+							      G_PARAM_READWRITE |
+                                                              G_PARAM_STATIC_STRINGS));
+	g_object_class_install_property (g_object_class,
+					 PROP_SCALE,
+					 g_param_spec_double ("max-scale",
+							      "Maximum Scale",
+							      "Maximum scale factor",
+							      0., G_MAXDOUBLE, DEFAULT_MAX_SCALE,
+							      G_PARAM_READWRITE |
+                                                              G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (g_object_class,
 					 PROP_SIZING_MODE,
 					 g_param_spec_enum ("sizing-mode",
@@ -239,6 +280,15 @@ ev_document_model_class_init (EvDocumentModelClass *klass)
 							    EV_SIZING_FIT_WIDTH,
 							    G_PARAM_READWRITE |
                                                             G_PARAM_STATIC_STRINGS));
+	g_object_class_install_property (g_object_class,
+					 PROP_PAGE_LAYOUT,
+					 g_param_spec_enum ("page-layout",
+							    "Page Layout",
+							    "Current page layout",
+							    EV_TYPE_PAGE_LAYOUT,
+							    EV_PAGE_LAYOUT_SINGLE,
+							    G_PARAM_READWRITE |
+							    G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (g_object_class,
 					 PROP_CONTINUOUS,
 					 g_param_spec_boolean ("continuous",
@@ -292,8 +342,8 @@ ev_document_model_init (EvDocumentModel *model)
 	model->sizing_mode = EV_SIZING_FIT_WIDTH;
 	model->continuous = TRUE;
 	model->inverted_colors = FALSE;
-	model->min_scale = 0.;
-	model->max_scale = G_MAXDOUBLE;
+	model->min_scale = DEFAULT_MIN_SCALE;
+	model->max_scale = DEFAULT_MAX_SCALE;
 }
 
 EvDocumentModel *
@@ -427,6 +477,8 @@ ev_document_model_set_max_scale (EvDocumentModel *model,
 
 	if (model->scale > max_scale)
 		ev_document_model_set_scale (model, max_scale);
+
+	g_object_notify (G_OBJECT (model), "max-scale");
 }
 
 gdouble
@@ -450,6 +502,8 @@ ev_document_model_set_min_scale (EvDocumentModel *model,
 
 	if (model->scale < min_scale)
 		ev_document_model_set_scale (model, min_scale);
+
+	g_object_notify (G_OBJECT (model), "min-scale");
 }
 
 gdouble
@@ -482,6 +536,47 @@ ev_document_model_get_sizing_mode (EvDocumentModel *model)
 	return model->sizing_mode;
 }
 
+static void
+_ev_document_model_set_dual_page_internal (EvDocumentModel *model,
+                                           gboolean         dual_page)
+{
+	g_return_if_fail (EV_IS_DOCUMENT_MODEL (model));
+
+	dual_page = dual_page != FALSE;
+
+	if (dual_page == model->dual_page)
+		return;
+
+	model->dual_page = dual_page;
+
+	g_object_notify (G_OBJECT (model), "dual-page");
+}
+
+void
+ev_document_model_set_page_layout (EvDocumentModel *model,
+				   EvPageLayout	    layout)
+{
+	g_return_if_fail (EV_IS_DOCUMENT_MODEL (model));
+
+	if (layout == model->page_layout)
+		return;
+
+	model->page_layout = layout;
+
+	g_object_notify (G_OBJECT (model), "page-layout");
+
+	/* set deprecated property as well */
+	_ev_document_model_set_dual_page_internal (model, layout == EV_PAGE_LAYOUT_DUAL);
+}
+
+EvPageLayout
+ev_document_model_get_page_layout (EvDocumentModel *model)
+{
+	g_return_val_if_fail (EV_IS_DOCUMENT_MODEL (model), EV_PAGE_LAYOUT_SINGLE);
+
+	return model->page_layout;
+}
+
 void
 ev_document_model_set_rotation (EvDocumentModel *model,
 				gint             rotation)
@@ -559,21 +654,12 @@ void
 ev_document_model_set_dual_page (EvDocumentModel *model,
 				 gboolean         dual_page)
 {
+	EvPageLayout layout;
+
 	g_return_if_fail (EV_IS_DOCUMENT_MODEL (model));
 
-	dual_page = dual_page != FALSE;
-
-	if (dual_page == model->dual_page)
-		return;
-
-	model->dual_page = dual_page;
-
-	g_object_notify (G_OBJECT (model), "dual-page");
-
-        if (dual_page && model->dual_page_odd_left) {
-                model->dual_page_odd_left = FALSE;
-                g_object_notify (G_OBJECT (model), "dual-odd-left");
-        }
+	layout = dual_page ? EV_PAGE_LAYOUT_DUAL : EV_PAGE_LAYOUT_SINGLE;
+	ev_document_model_set_page_layout (model, layout);
 }
 
 gboolean
@@ -598,11 +684,6 @@ ev_document_model_set_dual_page_odd_pages_left (EvDocumentModel *model,
 	model->dual_page_odd_left = odd_left;
 
 	g_object_notify (G_OBJECT (model), "dual-odd-left");
-
-        if (odd_left && model->dual_page) {
-                model->dual_page = FALSE;
-                g_object_notify (G_OBJECT (model), "dual-page");
-        }
 }
 
 gboolean
