@@ -40,7 +40,8 @@ struct _EvHistoryPrivate {
 
         EvDocumentModel *model;
         gulong           page_changed_handler_id;
-        gboolean         activating_current_link;
+
+        guint            frozen;
 };
 
 G_DEFINE_TYPE (EvHistory, ev_history, G_TYPE_OBJECT)
@@ -106,6 +107,12 @@ ev_history_init (EvHistory *history)
 	history->priv = G_TYPE_INSTANCE_GET_PRIVATE (history, EV_TYPE_HISTORY, EvHistoryPrivate);
 }
 
+static gboolean
+ev_history_is_frozen (EvHistory *history)
+{
+        return history->priv->frozen > 0;
+}
+
 void
 ev_history_add_link (EvHistory *history,
                      EvLink    *link)
@@ -113,7 +120,7 @@ ev_history_add_link (EvHistory *history,
 	g_return_if_fail (EV_IS_HISTORY (history));
 	g_return_if_fail (EV_IS_LINK (link));
 
-        if (history->priv->activating_current_link)
+        if (ev_history_is_frozen (history))
                 return;
 
         if (ev_history_go_to_link (history, link))
@@ -137,11 +144,11 @@ ev_history_add_link (EvHistory *history,
 static void
 ev_history_activate_current_link (EvHistory *history)
 {
-        history->priv->activating_current_link = TRUE;
+        ev_history_freeze (history);
         g_signal_handler_block (history->priv->model, history->priv->page_changed_handler_id);
         g_signal_emit (history, signals[ACTIVATE_LINK], 0, history->priv->current);
         g_signal_handler_unblock (history->priv->model, history->priv->page_changed_handler_id);
-        history->priv->activating_current_link = FALSE;
+        ev_history_thaw (history);
 
         g_signal_emit (history, signals[CHANGED], 0);
 }
@@ -151,7 +158,7 @@ ev_history_can_go_back (EvHistory *history)
 {
         g_return_val_if_fail (EV_IS_HISTORY (history), FALSE);
 
-        return history->priv->back_list != NULL;
+        return history->priv->back_list != NULL && !ev_history_is_frozen (history);
 }
 
 void
@@ -159,7 +166,7 @@ ev_history_go_back (EvHistory *history)
 {
         g_return_if_fail (EV_IS_HISTORY (history));
 
-        if (!history->priv->current || !history->priv->back_list)
+        if (!history->priv->current || !history->priv->back_list || ev_history_is_frozen (history))
                 return;
 
         history->priv->forward_list = g_list_prepend (history->priv->forward_list,
@@ -176,7 +183,7 @@ ev_history_can_go_forward (EvHistory *history)
 {
         g_return_val_if_fail (EV_IS_HISTORY (history), FALSE);
 
-        return history->priv->forward_list != NULL;
+        return history->priv->forward_list != NULL && !ev_history_is_frozen (history);
 }
 
 void
@@ -184,7 +191,7 @@ ev_history_go_forward (EvHistory *history)
 {
         g_return_if_fail (EV_IS_HISTORY (history));
 
-        if (!history->priv->current || !history->priv->forward_list)
+        if (!history->priv->current || !history->priv->forward_list || ev_history_is_frozen (history))
                 return;
 
         history->priv->back_list = g_list_prepend (history->priv->back_list,
@@ -215,7 +222,7 @@ ev_history_go_to_link (EvHistory *history,
         g_return_val_if_fail (EV_IS_HISTORY (history), FALSE);
         g_return_val_if_fail (EV_IS_LINK (link), FALSE);
 
-        if (!history->priv->current || (!history->priv->back_list && !history->priv->forward_list))
+        if (!history->priv->current || (!history->priv->back_list && !history->priv->forward_list) || ev_history_is_frozen (history))
                 return FALSE;
 
         l = g_list_find_custom (history->priv->back_list, link, (GCompareFunc)compare_link);
@@ -277,6 +284,23 @@ ev_history_get_forward_list (EvHistory *history)
         return history->priv->forward_list;
 }
 
+void
+ev_history_freeze (EvHistory *history)
+{
+        g_return_if_fail (EV_IS_HISTORY (history));
+
+        history->priv->frozen++;
+}
+
+void
+ev_history_thaw (EvHistory *history)
+{
+        g_return_if_fail (EV_IS_HISTORY (history));
+        g_return_if_fail (history->priv->frozen > 0);
+
+        history->priv->frozen--;
+}
+
 static gint
 ev_history_get_current_page (EvHistory *history)
 {
@@ -331,6 +355,9 @@ ev_history_add_link_for_page (EvHistory *history,
         gchar        *page_label;
         gchar        *title;
 
+        if (ev_history_is_frozen (history))
+                return;
+
         if (ev_history_get_current_page (history) == page)
                 return;
 
